@@ -9,7 +9,7 @@ use XS::Install::Deps;
 use XS::Install::Util;
 use XS::Install::Payload;
 
-our $VERSION = '1.2.5';
+our $VERSION = '1.2.6';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile not_available/;
@@ -548,7 +548,14 @@ sub process_test {
     ;
     
     my $mm_args = makemaker_args(%args);
-    return has_binary($mm_args) ? $mm_args : undef;
+    return undef unless has_binary($mm_args);
+    
+    if (my $prereq = $mm_args->{PREREQ_PM}) {
+        my $testrq = $params->{TEST_REQUIRES};
+        $testrq->{$_} //= $prereq->{$_} for grep {$_ ne $THIS_MODULE} keys %$prereq;
+    }
+    
+    return $mm_args;
 }
 
 sub process_test_makefile {
